import { NgModule } from '@angular/core';
import { PreloadAllModules, RouterModule, Routes } from '@angular/router';
import {AuthGuard} from "./authentification/auth.guard";

const routes: Routes = [
  {
    path: 'home',
    loadChildren: () => import('./pages/home/home.module').then(m => m.HomePageModule)
  },
  {
    path: '',
    redirectTo: 'home',
    pathMatch: 'full'
  },
  {
    path: 'login',
    loadChildren: () => import('./pages/login/login.module').then( m => m.LoginPageModule)
  },
  {
    path: 'register',
    loadChildren: () => import('./pages/register/register.module').then( m => m.RegisterPageModule)
  },
  {
    path: 'admin',
    loadChildren: () => import('./pages/admin/admin.module').then( m => m.AdminPageModule),

  },
  {
    path: 'verify-email',
    loadChildren: () => import('./pages/verify-email/verify-email.module').then( m => m.VerifyEmailPageModule)
  },
  {
    path: 'forgot-password',
    loadChildren: () => import('./pages/forgot-password/forgot-password.module').then( m => m.ForgotPasswordPageModule)
  },
  {
    path: 'miralin-grafic',
    loadChildren: () => import('./pages/miralin-grafic/miralin-grafic.module').then( m => m.MiralinGraficPageModule),
    canActivate:[AuthGuard],
  },
  {
    path: 'lista-estaciones',
    loadChildren: () => import('./pages/lista-estaciones/lista-estaciones.module').then( m=> m.ListaEstacionesPageModule),
    canActivate:[AuthGuard],
  },

  {
    path: 'caducidad-titulos',
    loadChildren: () => import('./pages/caducidad-titulos/caducidad-titulos.module').then( m => m.CaducidadTitulosPageModule),
    canActivate:[AuthGuard],
  },
  // miralin detail
  { path: 'miralin-estacion/:id/:linea', loadChildren: () => import('./pages/miralin-estacion/miralin-estacion.module').then(
    m => m.MiralinEstacionPageModule), canActivate:[AuthGuard],
  },
  {
    path: 'zonas',
    loadChildren: () => import('./pages/zonas/zonas.module').then( m => m.ZonasPageModule),
    canActivate:[AuthGuard],
  },
  {
    path: 'codigos',
    loadChildren: () => import('./pages/codigos/codigos.module').then( m => m.CodigosPageModule), canActivate:[AuthGuard],
  },
  {
    path: 'calendario',
    loadChildren: () => import('./pages/calendario/calendario.module').then( m => m.CalendarioPageModule),
    canActivate:[AuthGuard],
  },


];

@NgModule({
  imports: [
    RouterModule.forRoot(routes, { preloadingStrategy: PreloadAllModules })
  ],
  exports: [RouterModule]
})
export class AppRoutingModule { }
