import {Component, OnInit, ViewChild} from '@angular/core';
import {ServiceEstationsService} from "../../../service/service-estations.service";
import {ServiceTrensService} from "../../../service/service-trens.service";
import {ServiceEstacionsLiniaService} from "../../../service/service-estacions-linia.service";
import {IonSegment, NavParams} from "@ionic/angular";
import {Storage} from "@ionic/storage";
import {Router} from "@angular/router";
import {LoginPage} from "../login/login.page";
import {AuthService} from "../../../service/auth.service";


export const TIME_OF_REQUEST = 7000;


@Component({
  selector: 'app-home',
  templateUrl: 'home.page.html',
  styleUrls: ['home.page.scss'],
})

export class HomePage implements OnInit{

  @ViewChild(IonSegment, {static: true}) segment: IonSegment;

  liniaSeleccionada:any;
  lineas = [];
  trains = [];
  trenesVia1 = [];
  trenesVia2 = [];
  totalTrainsV12 = [];
  estacionesPorLinea = [];

  posicionAnterior = [];
  threadPositionsTrains;
  checked:any = false;

  time_request: any;
  // TODO encender thread al iniciar la aplicacion y poner el selector con una linea seleccionada que se guardara

  constructor(
    private getStationsService: ServiceEstationsService,
    private getTrainsService: ServiceTrensService,
    private getStationsForLinia: ServiceEstacionsLiniaService,

    private storage: Storage,
    private route: Router,
    private authService: AuthService

  ) {}

  estaIniciadaSesion() {
    this.storage.get('isVerified').then(res => {
      console.log(res);
      if(res!= null) {
        this.route.navigate(['admin']);
      } else {
        this.route.navigate(['login']);
      }
    });
  }
  ionViewWillEnter() {
    this.liniaSeleccionada = 'L1';
    console.log('linia: ' + this.liniaSeleccionada);
    this.getStationsLine();
    this.getTrainsLine('1');
    this.cambioDeLinea(this.liniaSeleccionada);


  }

  ngOnInit(): void {


  }

  // metodo para cargar las lineas
  async getStationsLine() {
    this.lineas = [];

    await this.getStationsService.getStations().subscribe(resp => {
      // solo guardamos las lineas que nos reportaran datos. Por ahora L10S - L10N - L9S - L9S -FM, no tienen datos
      resp.features.forEach(response => {

        if (response.properties.NOM_LINIA !== 'FM' &&
          response.properties.NOM_LINIA !== 'L10S' &&
          response.properties.NOM_LINIA !== 'L10N' &&
          response.properties.NOM_LINIA !== 'L9S' &&
          response.properties.NOM_LINIA !== 'L9N') {

          this.lineas.push(response.properties);
        }

      });
      // ordenamos las lineas por CODIGO
      this.lineas.sort(function(a, b){
        if(a.CODI_LINIA < b.CODI_LINIA) { return -1; }
        if(a.CODI_LINIA > b.CODI_LINIA) { return 1; }
        return 0;
      });

      // añadimos un nuevo item al objeto lineas
      for (let i = 0; i < this.lineas.length; i++) {
        // console.log(this.lineas[i]);

        switch (this.lineas[i].NOM_LINIA) {
          case 'L1':
            this.lineas[i]['img'] = '/assets/img/l1.png';
            break;
          case 'L2':
            this.lineas[i]['img'] = '/assets/img/l2.png';
            break;
          case 'L3':
            this.lineas[i]['img'] = '/assets/img/l3.png';
            break;
          case 'L4':
            this.lineas[i]['img'] = '/assets/img/l4.png';
            break;
          case 'L5':
            this.lineas[i]['img'] = '/assets/img/l5.jpg';
            break;
          case 'L11':
            this.lineas[i]['img'] = '/assets/img/l11.jpg';
            break;
        }
      }

    }, error => {
      alert('No hi ha connexió a hores d´ara...');
    });

  }

  async threadActivation (liniaNum) {


    // thread de consulta trenes
    this.threadPositionsTrains = setInterval(() => {
      this.getTrainsLine(liniaNum);

    }, TIME_OF_REQUEST);
  }

  async cambioDeLinea(item) {

    await clearInterval(this.threadPositionsTrains);
    this.estacionesPorLinea = [];
    const liniaNum = parseInt(item.detail.value.match(/\d+/g));
    // const num = String(liniaNum).match(/\d+/);

    await this.getStationsMetro(liniaNum);
    await this.getTrainsLine(liniaNum);
    await this.threadActivation(liniaNum);

  }
  // metodo para obtener las estaciones. Sele pasa la linia seleccionada por parametro
  async getStationsMetro(linia) {

    const auxEstacionesPorLinia = [];
    const parseStrEstacionesPorLinia = [];
    await this.getStationsForLinia.getStationsMetro(linia).subscribe(res => {

      auxEstacionesPorLinia.push(res.features);
      // console.log(auxEstacionesPorLinia[2]);
      for (let i = 0; i < auxEstacionesPorLinia[0].length; i++){
        parseStrEstacionesPorLinia.push(auxEstacionesPorLinia[0][i].properties);
      }


      parseStrEstacionesPorLinia.forEach(elem =>{
        const strAux = elem.ID_ESTACIO_LINIA.toString;
        this.estacionesPorLinea.push({
          CODI_ESTACIO: elem.CODI_ESTACIO.toString(),
          CODI_ESTACIO_LINIA: elem.CODI_ESTACIO_LINIA.toString(),
          CODI_GRUP_ESTACIO: elem.CODI_GRUP_ESTACIO.toString(),
          CODI_LINIA: elem.CODI_LINIA.toString(),
          ID_ESTACIO: elem.ID_ESTACIO.toString(),
          ID_ESTACIO_LINIA: elem.ID_ESTACIO_LINIA.toString(),
          ID_LINIA: elem.ID_LINIA,
          ID_TIPUS_ACCESSIBILITAT: elem.ID_TIPUS_ACCESSIBILITAT,
          ID_TIPUS_ESTAT: elem.ID_TIPUS_ESTAT,
          ID_TIPUS_SERVEI: elem.ID_TIPUS_SERVEI,
          NOM_ESTACIO: elem.NOM_ESTACIO,
          NOM_LINIA: elem.NOM_LINIA,
          NOM_TIPUS_ACCESSIBILITAT: elem.NOM_TIPUS_ACCESSIBILITAT,
          NOM_TIPUS_ESTAT: elem.NOM_TIPUS_ESTAT,

        });
      });
      // ordenamos las lineas por CODIGO
      this.estacionesPorLinea.sort(function(a, b){
        if(a.CODI_ESTACIO_LINIA < b.CODI_ESTACIO_LINIA) { return -1; }
        if(a.CODI_ESTACIO_LINIA > b.CODI_ESTACIO_LINIA) { return 1; }
        return 0;
      });
      //console.log(this.estacionesPorLinea);
    }, errot => {
      alert('No hi ha connexió a hores d´ara...');
    });
  }

  // metodo para obtener los trenes
  async getTrainsLine(line) {
    console.log('entro en getTrainsLine: ');
    this.trains = [];
    this.trenesVia1 = [];
    this.trenesVia2 = [];
    let auxEstacions;
    let parseInfo;

    await this.getTrainsService.getTrainsService(line).subscribe( resp => {
      // metemos cada info en cada via
      auxEstacions = resp;
      const auxTrenesVia1 = [];
      const auxTrenesVia2 = [];
      this.trenesVia1 = [];
      this.trenesVia2 = [];
      // console.log('transit: ');
      // console.log(resp);
      for (const key of auxEstacions){
        // pasamos la info que nos interesa
        parseInfo = [
          {codi_estacio: key.codi_estacio.toString()},
          {codi_linia: key.codi_linia},
          {codi_via: key.codi_via},
          {percent_ocupacio_estacio_sortida: key.ocupacio_estacio_sortida.percentatge_ocupacio},
          {temps_arrivada: key.propers_trens[0].temps_arribada},
          {temps_restant: key.propers_trens[0].temps_restant},
          {desti_trayecte: key.propers_trens[0].desti_trajecte},
          {codi_servei: key.propers_trens[0].codi_servei},
          {info_tren: key.propers_trens[0].info_tren},

        ];

        if (key.codi_via === 1){
          // los metemos en un auxiliar, de esta forma podremos iterar, para guardar los que nos interesan
          // recordar que el array devuelve la estacion en la que estan o van a llegar y la siguiente
          auxTrenesVia1.push(parseInfo);
          auxTrenesVia1.forEach(res=>{
            let found = false;
            if (this.trenesVia1.length === 0){
              this.trenesVia1.push(res);
            }
            for (let i = 0; i < this.trenesVia1.length; i++){
              if (this.trenesVia1[i][7].codi_servei === res[7].codi_servei){
                found = true;
              }
            }
            if (!found){
              this.trenesVia1.push(res);
            }
          });
        } else if (key.codi_via === 2) {
          // los metemos en un auxiliar, de esta forma podremos iterar, para guardar los que nos interesan
          // recordar que el array devuelve la estacion en la que estan o van a llegar y la siguiente
          auxTrenesVia2.push(parseInfo);
          auxTrenesVia2.forEach(res=>{
            let found = false;
            if (this.trenesVia2.length === 0){
              this.trenesVia2.push(res);
            }
            for (let i = 0; i < this.trenesVia2.length; i++){
              if (this.trenesVia2[i][7].codi_servei === res[7].codi_servei){
                found = true;
              }
            }
            if (!found){
              this.trenesVia2.push(res);
            }
          });
        }
      }

      // observamos que los elementos de this.trenesVia1 + los elementos de this.trenesVia2,
      // son el total de trenes que circulan en esta linea
      //console.log(this.totalTrainsV12);
      // console.log(this.trenesVia1);
      // console.log(this.trenesVia2);

      this.setTrainsInTrack();

    }, errot => {
      alert('No hi ha connexió a hores d´ara 2...');
    });

  }

  async setTrainsInTrack() {
    let element;
    // console.log(this.trenesVia1.length);

    //recorremos estaciones
    await this.estacionesPorLinea.forEach(est => {
      let found_1 = false;
      let found_2 = false;
      let tren_v1 = -1;
      let tren_v2 = -1;
      // console.log(est.NOM_ESTACIO + ' ' + est.CODI_ESTACIO);
      for (let j = 0; j < this.trenesVia1.length; j++) {
        if (this.trenesVia1[j][0].codi_estacio === est.CODI_ESTACIO){
          est.hayTren_v1 = true;
          found_1 = true;
          tren_v1 = j;
        }
      }
      for (let j = 0; j < this.trenesVia2.length; j++) {
        if (this.trenesVia2[j][0].codi_estacio === est.CODI_ESTACIO){
          est.hayTren_v2 = true;
          found_2 = true;
          tren_v2 = j;
        }
      }
      if (!found_1) {
        element = document.getElementById('estacion_1_'.concat(est.CODI_ESTACIO)) as HTMLInputElement;
        element.checked = false;
        document.getElementById('tren_1_'.concat(est.CODI_ESTACIO)).innerHTML = '';
        // new borrar
        document.getElementById('percent1_'.concat(est.CODI_ESTACIO)).innerHTML = '';
        // dia 16/05
        // document.getElementById('temps1_'.concat(est.CODI_ESTACIO)).innerHTML = '';

      } else {
        let aux = 'tren_1_'.concat(this.trenesVia1[tren_v1][0].codi_estacio);
        element = document.getElementById('estacion_1_'.concat(est.CODI_ESTACIO)) as HTMLInputElement;
        element.checked = true;
        document.getElementById(aux).innerHTML = this.trenesVia1[tren_v1][7].codi_servei;

        // dia 16-05
        /*
        let temps = 'temps1_'.concat(this.trenesVia1[tren_v1][0].codi_estacio);
        let auxTemps = this.trenesVia1[tren_v1][4].temps_arrivada;
        let resTemps = this.passarMillisecondsToDate(auxTemps);
        document.getElementById(temps).innerHTML = resTemps;
        */
        // new pintar
        let perAux = 'percent1_'.concat(this.trenesVia1[tren_v1][0].codi_estacio);
        if (this.trenesVia1[tren_v1][8].info_tren.percentatge_ocupacio != null) {
          let percentAux = this.trenesVia1[tren_v1][8].info_tren.percentatge_ocupacio.toString();
          percentAux = percentAux.concat('%')
          document.getElementById(perAux).innerHTML = percentAux;
        }

        // let total_seconds = this.passarMillisecondsToDate(this.trenesVia1[tren_v1][4].temps_arrivada);
      }
      if (!found_2) {
        element = document.getElementById('estacion_2_'.concat(est.CODI_ESTACIO)) as HTMLInputElement;
        element.checked = false;
        document.getElementById('tren_2_'.concat(est.CODI_ESTACIO)).innerHTML = '';

        // new borrar
        document.getElementById('percent2_'.concat(est.CODI_ESTACIO)).innerHTML = '';
        // document.getElementById('temps2_'.concat(est.CODI_ESTACIO)).innerHTML = '';
      } else {
        let aux = 'tren_2_'.concat(this.trenesVia2[tren_v2][0].codi_estacio);
        element = document.getElementById('estacion_2_'.concat(est.CODI_ESTACIO)) as HTMLInputElement;
        element.checked = true;
        document.getElementById(aux).innerHTML = this.trenesVia2[tren_v2][7].codi_servei;

        // dia 16-05
        /*
        let temps = 'temps2_'.concat(this.trenesVia1[tren_v2][0].codi_estacio);
        let auxTemps = this.trenesVia1[tren_v2][4].temps_arrivada;
        let resTemps = this.passarMillisecondsToDate(auxTemps);
        document.getElementById(temps).innerHTML = resTemps;
        */

        // new pintar
        let perAux = 'percent2_'.concat(this.trenesVia2[tren_v2][0].codi_estacio);
        if (this.trenesVia2[tren_v2][8].info_tren.percentatge_ocupacio != null) {
          let percentAux = this.trenesVia2[tren_v2][8].info_tren.percentatge_ocupacio.toString();
          percentAux = percentAux.concat('%')
          document.getElementById(perAux).innerHTML = percentAux;
        }
      }
    }, errot => {
      alert('No hi ha connexió a hores d´ara 1...');
    });

  }
  /*
  async ionViewWillEnter() {
    await this.storage.get(this.key).then((val) => {
      this.liniaSeleccionada = val;
      if (this.liniaSeleccionada === null) {
        this.liniaSeleccionada = this.lineas[0].valor.toString();
      }
      console.log('El valor es: ', val);
    });
    console.log('ionViewWillEnter: ', this.liniaSeleccionada);
    this.trainIsInStation(this.liniaSeleccionada);
  }

  */
  passarMillisecondsToDate(milliseconds) {

    const date = new Date(milliseconds);
    const hora = date.getHours();
    const min = date.getMinutes();
    const sec = date.getSeconds();
    let auxhora, auxmin, auxsec;
    auxhora = (hora < 10 ? '0' : '') + hora;
    auxmin = (min < 10 ? '0' : '') + min;
    auxsec = (sec < 10 ? '0' : '') + sec;

    const dia = date.getDate();
    const mes = date.getMonth();
    const ani = date.getFullYear();
    let auxdia, auxmes;
    auxdia = (dia < 10 ? '0' : '') + dia;
    auxmes = (mes < 10 ? '0' : '') + mes;
    const fecha = auxdia + '/' + auxmes + '/' + ani;
    const time = (auxhora + ':' + auxmin);

    return time;
  }


}
