import {Component, Injectable, OnInit, ViewChild} from '@angular/core';
import {AlertController, IonSegment} from "@ionic/angular";
import {ActivatedRoute} from "@angular/router";
import {DataTmbInternalService} from "../../../service/data-tmb-internal.service";

@Component({
  selector: 'app-miralin-estacion',
  templateUrl: './miralin-estacion.page.html',
  styleUrls: ['./miralin-estacion.page.scss'],
})

export class MiralinEstacionPage implements OnInit {
  @ViewChild(IonSegment, {static: true}) segment: IonSegment;
  itemId: string;
  itemLin: string;
  trenesVia1: any[] = [];
  trenesVia2: any[] = [];
  llegada: string;
  data: any;

  llamadaThread: any;
  selvia = '';
  interruptor: boolean;
  via: string;


  constructor(
    private router: ActivatedRoute,
    private dataservice: DataTmbInternalService,
    public alertController: AlertController) {
    this.itemId = this.router.snapshot.paramMap.get('id');
    this.itemLin = this.router.snapshot.paramMap.get('linea');
    this.interruptor = false;

  }


  getTrainsTrack1(linea, estacion) {
    // Paramos el thread, es necesario aunque no este encendido
    // clearInterval(this.llamadaThread);
    this.dataservice.getTrains(linea, estacion).subscribe(resp => {
      this.trenesVia1 = [];
      // this.trenesVia1 = resp['data'].arrivals.tracks[0].trainsPositions;
      this.trenesVia1.push(...resp['data'].arrivals.tracks[0].trainsPositions);
      // this.trenesVia1[cont].push('chupado');
      let cont = 0;
      this.trenesVia1.forEach(item => {
        const arrival = item.arrivalTime;
        item['llegada'] = this.passarMillisecondsToDate(arrival);
        if (cont % 2 !== 0) {
          item['class'] = 'pintar' + linea;
        }
        cont++;
      });
      const arrival = resp['data'].arrivals.tracks[0].trainsPositions[0].arrivalTime;
      const resultado = this.passarMillisecondsToDate(arrival);

    });
  }

  getTrainsTrack2(linea, estacion) {

    // Paramos el thread, es necesario aunque no este encendido
    // clearInterval(this.llamadaThread);

    this.dataservice.getTrains(linea, estacion).subscribe(resp => {
      this.trenesVia2 = [];
      this.trenesVia2.push(...resp['data'].arrivals.tracks[1].trainsPositions);
      let cont = 0;
      this.trenesVia2.forEach(item => {
        // tslint:disable-next-line: no-shadowed-variable
        const arrival = item.arrivalTime;
        item['llegada'] = this.passarMillisecondsToDate(arrival);
        if (cont % 2 !== 0) {
          item['class'] = 'pintar' + linea;
        }
        cont++;
      });

      const arrival = resp['data'].arrivals.tracks[1].trainsPositions[0].arrivalTime;
      const resultado = this.passarMillisecondsToDate(arrival);
      console.log(resultado);

    });
  }

  segmentChanged(event) {

    this.via = 'Via 1';
    const valorSegmento = event.detail.value;
    this.selvia = valorSegmento;
    if (this.interruptor === true) {
      this.interruptor = false;
    }

    if (valorSegmento === 'via1') {
      if (this.interruptor === false) {
        this.interruptor = true;
        clearInterval(this.llamadaThread);
      }
      this.getTrainsTrack1(this.itemLin, this.itemId);

      this.llamadaThread = setInterval(() => {

        if (this.trenesVia1.length === 0) {
          clearInterval(this.llamadaThread);
          this.presentAlert();
        }
        this.getTrainsTrack1(this.itemLin, this.itemId);
      }, 2000);

    } else {
      this.via = 'Via 2';
      if (this.interruptor === false) {
        this.interruptor = true;
        clearInterval(this.llamadaThread);
      }

      this.getTrainsTrack2(this.itemLin, this.itemId);

      this.llamadaThread = setInterval(() => {
        if (this.trenesVia2.length === 0) {
          clearInterval(this.llamadaThread);
          this.presentAlert();
        }
        this.getTrainsTrack2(this.itemLin, this.itemId);
      }, 2000);
    }


    this.selvia = valorSegmento;

  }
  segmentAutoLoad(evento: string) {

    this.via = 'Via 1';
    const valorSegmento = evento;
    this.selvia = valorSegmento;
    if (this.interruptor === true) {
      this.interruptor = false;
    }

    if (valorSegmento === 'via1') {
      if (this.interruptor === false) {
        this.interruptor = true;
        clearInterval(this.llamadaThread);
      }
      this.getTrainsTrack1(this.itemLin, this.itemId);

      this.llamadaThread = setInterval(() => {

        if (this.trenesVia1.length === 0) {
          clearInterval(this.llamadaThread);
          this.presentAlert();
        }
        this.getTrainsTrack1(this.itemLin, this.itemId);
      }, 2000);

    } else {
      this.via = 'Via 2';
      if (this.interruptor === false) {
        this.interruptor = true;
        clearInterval(this.llamadaThread);
      }

      this.getTrainsTrack2(this.itemLin, this.itemId);

      this.llamadaThread = setInterval(() => {
        if (this.trenesVia2.length === 0) {
          clearInterval(this.llamadaThread);
          this.presentAlert();
        }
        this.getTrainsTrack2(this.itemLin, this.itemId);
      }, 2000);
    }


    this.selvia = valorSegmento;
  }

  ionViewDidEnter() {
    //  Seleccionamos el valor del segment por defecto
    this.segment.value = 'via1';

    this.segmentAutoLoad('via1');

  }

  ionViewWillLeave() {
    // mata el thread, justo cuando sale de la vista

    clearInterval(this.llamadaThread);

  }


  ngOnInit() {
    // variables que se habrian de guardar para comodidad del usuario

  }

  async presentAlert() {
    const alert = await this.alertController.create({
      header: 'Avís',
      subHeader: 'Conexió - Trens/Via',
      message: 'És possible que hi hagi un problema amb la connexió o bé, no hi ha trens en aquesta via.',
      buttons: ['OK']
    });

    await alert.present();
  }

  passarMillisecondsToDate(milliseconds) {

    const date = new Date(milliseconds);
    const hora = date.getHours();
    const min = date.getMinutes();
    const sec = date.getSeconds();
    let auxhora, auxmin, auxsec;
    auxhora = (hora < 10 ? '0' : '') + hora;
    auxmin = (min < 10 ? '0' : '') + min;
    auxsec = (sec < 10 ? '0' : '') + sec;

    const dia = date.getDate();
    const mes = date.getMonth();
    const ani = date.getFullYear();
    let auxdia, auxmes;
    auxdia = (dia < 10 ? '0' : '') + dia;
    auxmes = (mes < 10 ? '0' : '') + mes;
    const fecha = auxdia + '/' + auxmes + '/' + ani;
    const time = (auxhora + ':' + auxmin);

    return time;
  }

}
