import {Component, OnInit, ViewChild} from '@angular/core';

import {DataTmbInternalService} from "../../../service/data-tmb-internal.service";
import {IonSegment} from "@ionic/angular";
import { Storage } from '@ionic/storage';


export const TIME_OF_REQUEST = 7000;
@Component({
  selector: 'app-miralin-grafic',
  templateUrl: './miralin-grafic.page.html',
  styleUrls: ['./miralin-grafic.page.scss'],
})
export class MiralinGraficPage implements OnInit {

  @ViewChild(IonSegment, {static: true}) segment: IonSegment;

  auxTrainsEst1: any[] = [];
  auxTrainsEst2: any[] = [];
  trains: any[] = [];
  auxTrains: any[] = [];
  estaciones: any[] = [];
  infoTrains: any[] = [];
  averageMDM: string;
  estadoRegulacio: string;
  estadoLinea: boolean;
  regularitatIndex: string;
  llamadaThread: any;
  totalTrensLinea: string;
  descStatus = 'No Status';
  liniaSeleccionada;
  key = 'linea';

  lineas = [
    {name: 'Línea 1', img: '/assets/img/l1.png', valor: 1},
    {name: 'Línea 2', img: '/assets/img/l2.png', valor: 2},
    {name: 'Línea 3', img: '/assets/img/l3.png', valor: 3},
    {name: 'Línea 4', img: '/assets/img/l4.png', valor: 4},
    {name: 'Línea 5', img: '/assets/img/l5.jpg', valor: 5},
    {name: 'Línea 11', img: '/assets/img/l11.jpg', valor: 11}
  ];

  linea = '';
  complete = true;


  constructor(private dataService: DataTmbInternalService, private storage: Storage) {
  }
  ngOnInit() {

    this.storage.get('linia').then((val) => {
      this.liniaSeleccionada = val;
      if (this.liniaSeleccionada === null) {
        this.liniaSeleccionada = this.lineas[0].valor.toString();
      }
      console.log('Storage: ' + this.liniaSeleccionada);
    });

    this.trainIsInStation(this.liniaSeleccionada);
    // linea por defecto
    // this.segment.value = this.lineas[0].valor.toString();
    // this.getStationsLine(this.segment.value);
    // this.getTrains(this.segment.value);
  }

  async getStationsLine(event) {
    this.estaciones = [];
    await this.dataService.getStations(event).subscribe(resp => {
      this.estaciones.push(...resp['data'].features);
      this.getTrains(event);
    }, error => {
      alert('No hi ha connexió a hores d´ara...');
    });

  }

  getTrainsFromStation(linea, station, auxStation) {
    this.auxTrainsEst1 = [];
    this.auxTrainsEst2 = [];
    this.trains = [];

    this.dataService.getEventsTrains(linea, station, auxStation).subscribe(

      resp => {

        this.auxTrainsEst1.push(...resp.primero['data'].arrivals.tracks[0].trainsPositions);
        this.auxTrainsEst2.push(...resp.segundo['data'].arrivals.tracks[0].trainsPositions);
        if (this.auxTrainsEst1.length >= this.auxTrainsEst2.length) {

          this.estadoLinea = resp.primero['data'].arrivals.stopped;
          this.trains = this.auxTrainsEst1;
          this.trainIsInStation(linea);
          this.estadoRegulacio = resp.primero['data'].arrivals.adjustmentState;
          this.regularitatIndex = resp.primero['data'].arrivals.regularityIndex;
          this.averageMDM = this.calculoMDM(resp.primero['data'].arrivals.secAverage);
          this.totalTrensLinea = resp.primero['data'].arrivals.totalTrains;
        } else {
          this.estadoLinea = resp.segundo['data'].arrivals.stopped;
          this.trains = this.auxTrainsEst2;
          this.trainIsInStation(linea);
          this.estadoRegulacio = resp.segundo['data'].arrivals.adjustmentState;
          this.regularitatIndex = resp.segundo['data'].arrivals.regularityIndex;
          this.averageMDM = String(this.calculoMDM(resp.segundo['data'].arrivals.secAverage));
          this.totalTrensLinea = resp.segundo['data'].arrivals.totalTrains;
        }
        this.setEstadoLinea(this.estadoLinea);
        this.setEstadoRegulalcio(this.estadoRegulacio);

      }, error => {
        alert('No hi ha connexió a hores d´ara...');
        this.setEstadoLinea('nc');
      });
  }
  setEstadoLinea(item) {
    let con, stop, desc;
    con = document.getElementById('liniaOk');
    stop = document.getElementById('liniaStop');
    desc = document.getElementById('liniaNoStatus');
    // la linea NO esta parada
    if (item === false) {
      // verde
      con.classList.add('led-green');
      con.classList.remove('led-green1');
      stop.classList.remove('led-red');
      stop.classList.add('led-red1');
      this.descStatus = 'Linia OK';
      // la linea esta parada
    } else if (item === true) {
      // rojo
      stop.classList.add('led-red');
      con.classList.remove('led-green');
      stop.classList.remove('led-red1');
      con.classList.add('led-green1');
      this.descStatus = 'Stop';
      // no se sabe el estado de la linea
    } else {
      con.classList.remove('led-green');
      stop.classList.remove('led-red1');
      this.descStatus = 'No Status';
    }
  }

  setEstadoRegulalcio(item) {
    let con, stop, desc;
    con = document.getElementById('ledConectado');
    stop = document.getElementById('ledDesc');
    desc = document.getElementById('ledDesconectado');

    // estado de la regulacion
    if (item === 'CONNECTED') {
      // verde
      con.classList.add('led-green');
      con.classList.remove('led-green1');
      stop.classList.remove('led-red');
      stop.classList.add('led-red1');


    } else if (item === 'DISCONNECTED') {
      // rojo
      stop.classList.add('led-red');
      con.classList.remove('led-green');
      stop.classList.remove('led-red1');
      con.classList.add('led-green1');

    }
  }

  getTrains(linea) {
    let station;
    let auxStation;
    clearInterval(this.llamadaThread);
    switch (linea) {
      case '1':
        // miramos en la 118 y en la 133
        station = 118;
        auxStation = 133;
        this.getTrainsFromStation(linea, station, auxStation);
        this.llamadaThread = setInterval(() => {
          this.getTrainsFromStation(linea, station, auxStation);
        }, TIME_OF_REQUEST);

        break;
      case '2': // miramos en la 212 y en la 223
        station = 212;
        auxStation = 223;
        this.getTrainsFromStation(linea, station, auxStation);
        this.llamadaThread = setInterval(() => {
          this.getTrainsFromStation(linea, station, auxStation);
        }, TIME_OF_REQUEST);
        break;
      case '3': // miramos en la 320 y en la 333
        station = 320;
        auxStation = 333;
        this.getTrainsFromStation(linea, station, auxStation);
        this.llamadaThread = setInterval(() => {
          this.getTrainsFromStation(linea, station, auxStation);
        }, TIME_OF_REQUEST);
        break;
      case '4': // miramos en la 428 y en la 418
        station = 428;
        auxStation = 418;
        this.getTrainsFromStation(linea, station, auxStation);
        this.llamadaThread = setInterval(() => {
          this.getTrainsFromStation(linea, station, auxStation);
        }, TIME_OF_REQUEST);
        break;
      case '5': // miramos en la 515 y en la 531
        station = 515;
        auxStation = 531;
        this.getTrainsFromStation(linea, station, auxStation);
        this.llamadaThread = setInterval(() => {
          this.getTrainsFromStation(linea, station, auxStation);
        }, TIME_OF_REQUEST);
        break;
      case '11':
        // miramos en la TODO... hay que determinar que estacion se mira, en este caso solo miramos 1
        station = 1138;
        auxStation = 1138;
        this.getTrainsFromStation(linea, station, auxStation);
        this.llamadaThread = setInterval(() => {
          this.getTrainsFromStation(linea, station, auxStation);
        }, TIME_OF_REQUEST);
        break;
      default:
        break;

    }
  }

  calculoMDM(time) {
    let minutes = String(Math.floor( time / 60 ));
    let seconds = String(time % 60);
    // Anteponiendo un 0 a los minutos si son menos de 10
    minutes = minutes < '10' ? '0' + minutes : minutes;
    // Anteponiendo un 0 a los segundos si son menos de 10
    seconds = seconds < '10' ? '0' + seconds : seconds;
    const result = minutes + ':' + seconds;  // 161:30
    return result;
  }


  cambioDeLinea(event) {
    console.log('VALUE LINE --:');
    console.log(event);
    // guardamos la key
    this.liniaSeleccionada = event.detail.value;
    this.storage.set('linia', this.liniaSeleccionada);

    this.getStationsLine(event.detail.value);
  }


  async trainIsInStation(linea) {

    let i: number;
    i = 0;
    let info;
    this.infoTrains = [];
    let indice;

    // se realiza una copia del array de estaciones pero solo el codigo de la misma el resto de campos quedan vacios
    for (i = 0; i < this.estaciones.length; i++) {
      info = {codigo: '', via: '1', estacion: this.estaciones[i].properties.CODI_ESTACIO};
      this.infoTrains.push(info);
      info = {codigo: '', via: '2', estacion: this.estaciones[i].properties.CODI_ESTACIO};
      this.infoTrains.push(info);
    }

    await this.trains.forEach(item => {
      this.infoTrains.forEach(aux => {
        if (item.stopCode === aux.estacion && aux.via === String(item.track)) {
          info = {
            codigo: item.trainCode,
            via: aux.via,
            estacion: aux.estacion
          };
          indice = this.infoTrains.findIndex(x => x.estacion === aux.estacion && x.via === aux.via);
          this.infoTrains.splice(indice, 1, info);
        }
      });

      for (let i = 0; i < this.infoTrains.length; i++){
        let element;
        if (this.infoTrains[i].codigo !== '') {
          if (this.infoTrains[i].via === '1') {
            element = document.getElementById('v1_' + this.infoTrains[i].estacion ) as HTMLInputElement;
            // console.log(element);
            element.checked = true;
            document.getElementById(this.infoTrains[i].estacion + '_via_1').innerHTML = this.infoTrains[i].codigo;
          }
          if (this.infoTrains[i].via === '2') {
            element = document.getElementById('v2_' + this.infoTrains[i].estacion) as HTMLInputElement;
            element.checked = true;
            document.getElementById(this.infoTrains[i].estacion + '_via_2').innerHTML = this.infoTrains[i].codigo;
          }
        } else {
          if (this.infoTrains[i].codigo === '' && this.infoTrains[i].via === '1') {
            element = document.getElementById('v1_' + this.infoTrains[i].estacion) as HTMLInputElement;
            element.checked = false;
            document.getElementById(this.infoTrains[i].estacion + '_via_1').innerHTML = '';
          }
          if (this.infoTrains[i].codigo === '' && this.infoTrains[i].via === '2') {
            element = document.getElementById('v2_' + this.infoTrains[i].estacion) as HTMLInputElement;
            element.checked = false;
            document.getElementById(this.infoTrains[i].estacion + '_via_2').innerHTML = '';
          }
        }

      }


    });


  }

  recuperarSeleccion(): boolean {
    let sel = false;
    this.storage.get('linia').then((val) => {
      this.liniaSeleccionada = val;
      if (this.liniaSeleccionada === null) {
        this.liniaSeleccionada = this.lineas[0].valor.toString();
        sel = true;
      }

    });

    return sel;
  }
  async ionViewWillEnter() {

    await this.storage.get('linia').then((val) => {
      this.liniaSeleccionada = val;
      if (this.liniaSeleccionada === null) {
        this.liniaSeleccionada = this.lineas[0].valor.toString();
      }

    });

    this.trainIsInStation(this.liniaSeleccionada);
  }

  ionViewWillLeave() {
    // mata el thread, justo cuando sale de la vista
    // set a key/value

    clearInterval(this.llamadaThread);

  }
}
