import { Injectable } from '@angular/core';
import {User} from "../app/interfaces/user";
import {AngularFireAuth} from "@angular/fire/auth";

import {AngularFirestore, AngularFirestoreDocument} from "@angular/fire/firestore";

import {Observable, of} from "rxjs";
import {switchMap} from "rxjs/operators";
import * as firebase from 'firebase';

@Injectable({
  providedIn: 'root'
})
export class AuthService {
  public user$: Observable<User>;

  constructor(public afAuth: AngularFireAuth, private afs: AngularFirestore) {
    this.user$ = this.afAuth.authState.pipe(switchMap((user) =>{
      if (user) {
        return this.afs.doc<User>(`users/${user.uid}`).valueChanges();
      }
      return of(null);
    }));
  }

  async resetPassword(email): Promise<void>{
    try {
      return this.afAuth.sendPasswordResetEmail(email);
    } catch (e) {
      console.log(e);
    }
  }

  async loginGoogle(): Promise<User>{
    try {
      const {user} = await this.afAuth.signInWithPopup(new firebase.default.auth.GoogleAuthProvider());
      this.updateUserDate(user);
      return user;
    } catch (e) {
      console.log(e);
    }
  }

  async register(email, password): Promise<User>{
    try{
      const {user} = await this.afAuth.createUserWithEmailAndPassword(email, password);
      await this.sendVerificationEmail();
      return user;
    }catch (e) {
      console.log(e);
    }
  }

  async login(email, password): Promise<User>{
    try{
      const {user} = await this.afAuth.signInWithEmailAndPassword(email.value, password.value);
      this.updateUserDate(user);
      return user;
    }catch (e) {
      console.log(e);
    }
  }

  async sendVerificationEmail(): Promise<void>{
    try{
       return (await this.afAuth.currentUser).sendEmailVerification();
    }catch (e) {
      console.log(e);
    }
  }

  isEmailVerify(user:User): boolean {
    return user.emailVerified === true ? true : false;
  }

  async logout():Promise<void>{
    try {
      await this.afAuth.signOut();
    } catch (e) {
      console.log(e);
    }
  }

  async updateUserDate(user:User) {
    const userRef: AngularFirestoreDocument<User> = this.afs.doc(`users/${user.uid}`);
    const data: User = {
      uid: user.uid,
      email: user.email,
      emailVerified: user.emailVerified,
      displayName: user.displayName
    };

    // si existe haremos un merge
    return userRef.set(data, {merge: true});
  }
}
